"""
Copyright 2008-2014 by Aerospike, Inc. All rights reserved.
THIS IS UNPUBLISHED PROPRIETARY SOURCE CODE. THE COPYRIGHT NOTICE
ABOVE DOES NOT EVIDENCE ANY ACTUAL OR INTENDED PUBLICATION.
"""


# -*- coding: utf-8 -*-
from constants import *


def get_jobs(cluster_obj, node_address):

    info = dict(address=node_address)
    node_obj = cluster_obj.get_node(node_address)

    if node_obj.get_status() == "on":
        info['node_status'] = "on"
        info['jobs'] = node_obj.get_jobs()
        info['memory'] = node_obj.get_memory_stats()
    else:
        info['node_status'] = "off"

    return info


def get_udfs(cluster_obj):

    cluster_status = cluster_obj.get_status()
    if cluster_status == "off":
        return {"cluster_status": "off"}

    udfs = {}
    node_addresses = cluster_obj.get_node_list()
    no_of_nodes = 0
    available_nodes = set()
    for node_address in node_addresses:
        node = cluster_obj.get_node(node_address)
        if node is None or node.get_status() == "off":
            continue

        result = node.get_udfs()
        if result == UNABLE_TO_CONNECT:
            continue
        available_nodes.add(node_address)

        for udf in result:
            try:
                # for udf like {'node_status': 'on', 'error': 'file_not_readable', 'filename': 's3'}
                data = udfs.get(udf["hash"], {'present_nodes': [],
                    'absent_nodes': [], 'synced': True})
            except:
                continue
            data['filename'] = udf.get('filename', NOT_AVAILABLE)
            data['type'] = udf.get('type', NOT_AVAILABLE)
            data['present_nodes'].append(node_address)
            data['cache_size'] = NOT_AVAILABLE
            udfs[udf["hash"]] = data

        no_of_nodes += 1

    for udf, details in list(udfs.items()):
        if len(details['present_nodes']) != no_of_nodes:
            details['synced'] = False
            details['absent_nodes'] = list(
                available_nodes - set(details['present_nodes']))

    response = dict(udfs=udfs, cluster_status="on")
    return response
